namespace StubAPI;


public static class Extensions
{
    internal static Task<T?> AddItem<T>(this IList<T> collection, T? item)
    {
        if(item == null || collection.Contains(item))
        {
            return Task.FromResult<T?>(default(T));
        }
        collection.Add(item);
        return Task.FromResult<T?>(item);
    }

    internal static Task<bool> DeleteItem<T>(this IList<T> collection, T? item)
    {
        if(item == null)
        {
            return Task.FromResult(false);
        }
        bool result = collection.Remove(item!);
        return Task.FromResult(result);
    }

    internal static Task<T?> UpdateItem<T>(this IList<T> collection, T? oldItem, T? newItem)
    {
        if(oldItem == null || newItem == null) return Task.FromResult<T?>(default(T));

        if(!collection.Contains(oldItem))
        {
            return Task.FromResult<T?>(default(T));
        }

        collection.Remove(oldItem!);
        collection.Add(newItem!);
        return Task.FromResult<T?>(newItem);
    }

}